/*
 * Copyright 2026 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.internal.buildtree;

import org.gradle.internal.service.ServiceRegistry;
import org.gradle.internal.service.scopes.Scope;
import org.gradle.internal.service.scopes.ServiceScope;

/**
 * Explicit container of the BuildTree-scoped services.
 * <p>
 * The use of this service should generally be avoided, except for setting up the parent services of the build-scope.
 */
@ServiceScope(Scope.BuildTree.class)
public class BuildTreeServices {

    private final ServiceRegistry services;

    public BuildTreeServices(ServiceRegistry buildTreeServices) {
        this.services = buildTreeServices;
    }

    public ServiceRegistry getServices() {
        return services;
    }
}
